@@ -4,7 +4,7 @@ function(conId,symbol,sectype,exch,primary,expiry,strike,
          comboleg,include_expired,secIdType="",secId="")
 {
   if(is.null(names(match.call()[-1])))
-    return(do.call("twsContract", rep(list(NULL), 14)))
+    return(do.call("twsContract", rep(list(""), 14)))
 
   structure(
             list(conId=conId,
@@ -79,7 +79,7 @@ as.twsContract.twsContractDetails <- function(x, ...)
 
 twsContractDetails <-
 function(version=NULL,
-         contract=do.call('twsContract',rep(list(NULL),13)),
+         contract=twsContract(),
          marketName=NULL,
          tradingClass=NULL,
          conId=NULL,
